import { Feed, FeedStoreState } from '@knocklabs/client';
import { StoreApi, UseBoundStore } from 'zustand';
export type Selector<T> = (state: FeedStoreState) => T;
/**
 * Access a Bounded Store instance by converting our vanilla store to a UseBoundStore
 * https://zustand.docs.pmnd.rs/guides/typescript#bounded-usestore-hook-for-vanilla-stores
 * Allow passing a selector down from useCreateNotificationStore OR useNotificationStore
 * We'll favor the the one passed later outside of useCreateNotificationStore instantiation
 */
declare function useCreateNotificationStore<T>(feedClient: Feed): UseBoundStore<StoreApi<FeedStoreState>>;
/**
 * A hook used to access content within the notification store.
 *
 * @example
 *
 * ```ts
 * const { items, metadata } = useNotificationStore(feedClient);
 * ```
 *
 * A selector can be used to access a subset of the store state.
 *
 * @example
 *
 * ```ts
 * const { items, metadata } = useNotificationStore(feedClient, (state) => ({
 *   items: state.items,
 *   metadata: state.metadata,
 * }));
 * ```
 */
declare function useNotificationStore(feedClient: Feed): FeedStoreState;
declare function useNotificationStore<T>(feedClient: Feed, selector: Selector<T>): T;
export { useCreateNotificationStore };
export default useNotificationStore;
//# sourceMappingURL=useNotificationStore.d.ts.map